<?php

namespace Drupal\tsi\Commands;

use Drush\Commands\DrushCommands;

/**
 * A drush command file.
 *
 * @package Drupal\tsi\Commands
 */
class TsiDrushCommands extends DrushCommands {

  /**
   * Drush command that imports a translation string.
   *
   * @param string $source
   *   Source string.
   * @param string $translated
   *   Translated string.
   * @param string $langcode
   *   Language (f.e 'de').
   * @param string $context
   *   The context of the translation (default = '')
   *
   * @command tsi:add
   * @aliases tsi
   * @usage tsi "Hello" "Hallo" de
   */
  public function tsi($source, $translated, $langcode, $context = '') {
    $svc = \Drupal::service('tsi.service');
    $svc->addTranslation($source, $translated, $langcode, $context);

    $info = "language: $langcode";
    if ($context) {
      $info .= " context: $context";
    }
    $this->output()->writeln("Translation added [$source -> $translated] ($info)");
  }

  /**
   * Drush command that imports a translation string.
   *
   * @param string $source
   *   Source string.
   * @param string $translated
   *   Translated string.
   * @param string $source2
   *   2nd source string.
   * @param string $translated2
   *   2nd translated string.
   * @param string $langcode
   *   Language (f.e 'de').
   * @param string $context
   *   The context of the translation (default = '')
   *
   * @command tpi:add
   * @aliases tpi
   * @usage tsi "Hello" "Hallo" "Hello2" "Hallo2" de
   */
  public function tpi($source, $translated, $source2, $translated2, $langcode, $context = '') {
    $svc = \Drupal::service('tsi.service');
    $svc->addPlural($source, $translated, $source2, $translated2, $langcode, $context);

    $info = "language: $langcode";
    if ($context) {
      $info .= " context: $context";
    }
    $this->output()->writeln("Translation added [$source -> $translated, $source2 -> $translated2] ($info)");
  }

}
