<?php

namespace Drupal\tsi;

use Drupal\Component\Gettext\PoItem;
use Drupal\locale\SourceString;
use Drupal\locale\StringStorageInterface;

/**
 * Translation String Import Service.
 *
 * Import Translation Strings directly.
 *
 */
class TsiService implements TsiServiceInterface {

  /**
   * String translation storage object.
   *
   * @var \Drupal\locale\StringStorageInterface
   */
  protected $localeStorage;

  /**
   * Constructs a new TsiService object.
   */
  public function __construct(StringStorageInterface $locale_storage) {
    $this->localeStorage = $locale_storage;
  }

  /**
   * {@inheritdoc}
   */
  public function addTranslation($source, $translated, $langcode, $context = '') {
    $string = $this->localeStorage->findString([
      'source' => $source,
      'context' => $context,
    ]);
    if (is_null($string)) {
      $string = new SourceString();
      $string->setString($source);
      $string->setStorage($this->localeStorage);
      $string->context = $context;
      $string->save();
    }

    $this->localeStorage->createTranslation([
      'lid' => $string->lid,
      'language' => $langcode,
      'translation' => $translated,
    ])->save();
    _locale_invalidate_js($langcode);
    _locale_refresh_translations([$langcode], [$string->lid]);
    _locale_refresh_configuration([$langcode], [$string->lid]);
  }

  /**
   * {@inheritdoc}
   */
  public function addPlural($source, $translated, $source2, $translated2, $langcode, $context = '') {
    $string = $this->localeStorage->findString([
      'source' => implode(PoItem::DELIMITER, [$source, $source2]),
      'context' => $context,
    ]);
    if (is_null($string)) {
      $string = new SourceString();
      $string->setPlurals([$source, $source2]);
      $string->setStorage($this->localeStorage);
      $string->context = $context;
      $string->save();
    }

    if ($translations = $this->localeStorage->getTranslations(['lid' => $string->lid, 'language' => $langcode, 'translated' => TRUE])) {
      $translation = reset($translations);
    }
    else {
      $translation = $this->localeStorage->createTranslation([
        'lid' => $string->lid,
        'language' => $langcode,
      ]);
    }
    $translation->setPlurals([$translated, $translated2]);
    $translation->save();
    _locale_invalidate_js($langcode);
    _locale_refresh_translations([$langcode], [$string->lid]);
    _locale_refresh_configuration([$langcode], [$string->lid]);
  }

}
